#!/bin/sh
# shellscript driver for netdisc/netvis run
# run from cron on some basis (daily, hourly ...)

# change the following 3 variables ###########
# working directories, subject to installation
# output files go here
WORK_DIR='/usr/home/network/netdisc'
# where netdisc, netreport, netvis are installed
BIN_DIR='/usr/local/bin'
# where web pages should be moved to
WEB_DIR='/usr/local/apache/htdocs/netdisc'
######### end things that need mods########## 

echo "start time: `date`"

# go to working directory
cd $WORK_DIR

FIRST=1   # assume this is the first time to run netdisc

# check if this is the first run
if [ -f routers.ip.A -a hosts.ip.A ] ; then
        FIRST=0 
fi

# discover the network
# The current run uses RID=B, then it is renamed using RID=A
echo "<1> Discover the network..."
$BIN_DIR/netdisc -rid B 

# combine two runs
echo "<2> Combine two runs..."
if [ $FIRST -eq 1 ]; then
	echo "First time run netreport..."
	$BIN_DIR/netreport -r routers.ip.B -h hosts.ip.B -dns  > /dev/null
	mv routers.ip.B.sorted routers.ip.C.sorted
	mv hosts.ip.B.sorted hosts.ip.C.sorted
else
	echo "Running netreport to combine different runs..."
	$BIN_DIR/netreport -r routers.ip -h hosts.ip -rid A B C -dns  > /dev/null
fi

# move the output of current run to 'A' 
echo "<3> Moving current run to A..."
mv routers.ip.B routers.ip.A
mv hosts.ip.B hosts.ip.A

$BIN_DIR/netreport -r routers.ip.A -h hosts.ip.A -dns -b > /dev/null

# generate top-level HTML pages (from this point on, all works are done on RID='C')
echo "<4> Generating top-level HTML pages..."

# takes sorted.C and makes netvis.inf which is DYNAMIC
$BIN_DIR/netvis -r routers.ip.C.sorted 

# takes netvis.inf and static netvis.pol and generates
# PNG file and first-level html which is the HTML map file
# (this is due to the switch -p)
$BIN_DIR/netvis -r routers.ip.C.sorted -p -H1 2 -fg netvis.png

# move to temp html directory
echo "<5> Moving to HTML subdirectory..."
mv netvis.html html
mv netvis.png html

# generate 2nd level pages
echo "<6> Generating 2nd level HTML pages..."
mkdir html
cd html
$BIN_DIR/netvis -r ../routers.ip.C.sorted -h ../hosts.ip.C.sorted -H2 http://jerry.cat.pdx.edu/cgi-bin/neturl.pl

# move all generated files to web directory
echo "<7> Moving to web directory..."
cp * $WEB_DIR
cp ../router.html $WEB_DIR
cp ../alert.html  $WEB_DIR
cp ../subnet.html  $WEB_DIR

# make switch run so that found switches are always in
# "logfile" switches.  No auto-html generation for that
# feature as of yet.  note that format of file is same as hosts.ip

cd $WORK_DIR
$BIN_DIR/netreport -h hosts.ip.A -dns -s switches.txt -c cdp.txt > /dev/null

cp switches.html cdp.html $WEB_DIR

# copy reports to WEB land
cp system.txt switches.txt cdp.txt bcd.txt mac.txt /home/network/public_html/reports

# concat global stats into one file
cat switches.stats netdisc.stats > /home/network/public_html/reports/netdisc.stats
echo "end time: `date`"
